PyZMQ Documentation — PyZMQ v2.1.1dev documentation

### Navigation

- index
- modules |
- next |
- home|
- search|
- API »

# PyZMQ Documentation

Release: | 2.1.1dev
Date: | January 11, 2011

Note

These docs are for pyzmq-2.1.1dev, but pyzmq has not made any significant changes to itself since 2.0.10, so they should apply just fine there as well.

PyZMQ versioning follows zeromq, so your pyzmq version should match those of your zeromq. The only changes at the pyzmq user’s level are the addition of a few socket types and socket options.

PyZMQ is the Python bindings for ØMQ, written almost entirely in Cython. This documentation currently contains notes on some important aspects of developing PyZMQ and an overview of what the ØMQ API looks like in Python. For information on how to use ØMQ in general, see the excellent ØMQ Manual.

Please don’t hesitate to report pyzmq issues to our tracker on GitHub.

# Notes from developing PyZMQ

- PyZMQ, Python2.5, and Python3
  - pyversion_compat.h
  - Bytes and Strings
  - Buffers
  - `__str__`
  - Exceptions
- PyZMQ and Unicode
  - First, Unicode in Python 2 and 3
  - What This Means for PyZMQ

# Using PyZMQ

- More Than Just Bindings
  - The Core as Bindings
  - Core Extensions
  - Extensions
- Devices in PyZMQ
  - BackgroundDevices
  - MonitoredQueue
- Tornado Eventloop with PyZMQ
  - `send`
  - `on_recv`
  - `flush`
- Asynchronous Logging via PyZMQ
  - PUB/SUB and Topics
  - PUBHandler
- The PyZMQ API
  - zmq
  - core.context
  - core.device
  - core.error
  - core.message
  - core.poll
  - core.socket
  - core.stopwatch
  - core.version
  - devices.basedevice
  - devices.monitoredqueue
  - devices.monitoredqueuedevice
  - eventloop.ioloop
  - eventloop.stack_context
  - eventloop.zmqstream
  - log.handlers
  - utils.initthreads
  - utils.jsonapi

# Indices and tables

- Index
- Module Index
- Search Page

# Links

- ØMQ Home
- PyZMQ Installation notes on the ZeroMQ website
- PyZMQ on GitHub
- Issue Tracker

### Navigation

- index
- modules |
- next |
- home|
- search|
- API »